% This software is offered under the GNU General Public License 3.0.  It 
% is offered without any warranty expressed or implied, including the 
% implied warranties of merchantability or fitness for a particular 
% purpose.
%
% Written by Nicholas Dwork, Copyright 2018

function out = cleanBScan( in, varargin )
  % out = cleanBScan( in [, noiseFraction] )
  %
  % Inputs:
  % in - the B-scan to be cleaned
  %
  % Optional Inputs:
  % noiseFraction - the top noiseFraction in the B-scan is assumed not to have sample
  %
  % Outputs:
  % out - the cleaned B-scan
  %
  % Written by Nicholas Dwork - copyright 2018

  gSig = 0.5;
  
  defaultNoiseFraction = 0.05;
  p = inputParser;
  p.addOptional( 'noiseFraction', defaultNoiseFraction, @isnumeric );
  p.parse( varargin{:} );
  noiseFraction = p.Results.noiseFraction;

  % Remove noise bias
  noiseIndx = floor( noiseFraction * size(in,1) );
  tmp = in( 1:noiseIndx, : );
  noiseMean = median( tmp(:) );
  deBiased = max( in - noiseMean, min( in(:) ) );

  % Remove speckle with a Gaussian filter
  out = imgaussfilt( deBiased, gSig );
end
