function [z0,zR,overlap,vShift,hShift,yShear] = findConfocal_yShearAndTrans( ...
  bscan1, bscan2, lambda0, deltaLambda, dLambda, trueZ0_mm, trueZR_mm, dx_mm, dz_mm )
  % [z0,zR] = findConfocal_yShearAndTrans( bscan1, bscan2 )
  %
  % Inputs:
  % bscan1 - first b-scan
  % bscan2 - second b-scan
  % lambda0, deltaLambda, and dLambda are fall-off parameters.  See the
  % makeFalloffFunction for details.
  %
  % Outputs:
  % z0 - the focal plane location (in pixels)
  % zR - the Rayleigh range (in pixels)
  %
  % Written by Nicholas Dwork - Copyright 2016
  %
  % This software is offered under the GNU General Public License 3.0.  It 
  % is offered without any warranty expressed or implied, including the 
  % implied warranties of merchantability or fitness for a particular 
  % purpose.

  % Function parameters
  searchFraction = 2.0;
  ransacThresh = 51;  % pixels

  bscan1_dB = intensity2dB( bscan1 );
  bscan2_dB = intensity2dB( bscan2 );

  regWithPoints = 1;  % Choose registration algorithm

  if( regWithPoints )
    [pts1,pts2] = findAndTrackPeaks( bscan1_dB, bscan2_dB, 'N', 100, ...
      'buffer', 25, 'w', 101, 'searchWidth', searchFraction*size(bscan1_dB) );
    figH1 = figure; imshowscale( bscan1_dB, 3 );  title( 'Features Image 1' );
    figH2 = figure; imshowscale( bscan2_dB, 3 );  title( 'Features Image 2' );

    sBScan = size( bscan1_dB );
    midX = ceil( (sBScan(2)+1)/2 );
    midY = ceil( (sBScan(1)+1)/2 );
    pts1(:,1) = pts1(:,1) - midX;  pts1(:,2) = pts1(:,2) - midY;
    pts2(:,1) = pts2(:,1) - midX;  pts2(:,2) = pts2(:,2) - midY;

    [yShear,t,inlierIndxs] = ransacYShearAndTrans( pts1, pts2, ransacThresh );

    pts2Plot1 = pts1;  pts2Plot2 = pts2;
    pts2Plot1(:,1) = pts2Plot1(:,1) + midX;  pts2Plot2(:,1) = pts2Plot2(:,1) + midX;
    pts2Plot1(:,2) = pts2Plot1(:,2) + midY;  pts2Plot2(:,2) = pts2Plot2(:,2) + midY;
    figure( figH1 ); labelImgPts( 3*pts2Plot1, 'inlierIndxs', inlierIndxs );
    figure( figH2 ); labelImgPts( 3*pts2Plot2, 'inlierIndxs', inlierIndxs );

    hShift = t(1);  vShift = t(2);
  else

    [vShift, hShift, rotation] = findTransRotWithPCC( bscan1_dB, bscan2_dB, ...
      'dTheta', 1*pi/180 );
    yShear = atan( rotation );
  end
  
  [z0, zR, overlap] = findConfocalParameters( bscan1, bscan2, hShift, vShift, yShear, ...
    lambda0, deltaLambda, dLambda, trueZ0_mm, trueZR_mm, dx_mm, dz_mm );
end


